==> mono-2.4.tar.bz2: mono-2.4/mcs/class/System.Data/System.Data/DataTableNewRowEventArgs.cs <==
//
// System.Data.DataTableClearEventArgs.cs
//
// Author:
//   Senganal T <tsenganal@novell.com>
//
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
// Copyright (C) Authors.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0
namespace System.Data
{
        public sealed class DataTableNewRowEventArgs : EventArgs
        {
                #region Fields
		private readonly DataRow _row;
		#endregion //Fields

                #region Constructors
                public DataTableNewRowEventArgs(DataRow row)
                {
                        _row = row;
		}
		#endregion // Constructors

                #region Properties
		public DataRow Row {
			get { return _row; }
		}
                #endregion // Properties
        }
}
#endif // NET_2_0

==> mono-4.0.1.28.tar.bz2: mono-4.0.1/mcs/class/System.Data/System.Data/DataTableNewRowEventArgs.cs <==
//
// System.Data.DataTableClearEventArgs.cs
//
// Author:
//   Senganal T <tsenganal@novell.com>
//
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
// Copyright (C) Authors.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System.Data
{
        public sealed class DataTableNewRowEventArgs : EventArgs
        {
                #region Fields
		private readonly DataRow _row;
		#endregion //Fields

                #region Constructors
                public DataTableNewRowEventArgs(DataRow dataRow)
                {
                        _row = dataRow;
		}
		#endregion // Constructors

                #region Properties
		public DataRow Row {
			get { return _row; }
		}
                #endregion // Properties
        }
}
